package com.ozs.service.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.pagehelper.PageHelper;
import com.ozs.service.entity.MsgAlarm;
import com.ozs.service.entity.vo.AlarmStatisticDto;
import com.ozs.service.entity.vo.AlarmStatisticMonthDto;
import com.ozs.service.entity.vo.AlarmStatisticResVo;
import com.ozs.service.entity.vo.AlarmStatisticVo;
import com.ozs.service.entity.vo.MsgAlarmVo;
import com.ozs.service.mapper.BaseDictDataMapper;
import com.ozs.service.mapper.MsgAlarmMapper;
import com.ozs.service.service.MsgAlarmService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.hssf.usermodel.*;
import org.apache.poi.ss.usermodel.*;
import org.springframework.beans.BeanUtils;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletResponse;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * <p>
 * 报警信息表 服务实现类
 * </p>
 *
 * @author ozs
 * @since 2023-02-22
 */
@Service
public class MsgAlarmServiceImpl extends ServiceImpl<MsgAlarmMapper, MsgAlarm> implements MsgAlarmService {
    @Autowired
    MsgAlarmMapper msgAlarmMapper;
    @Autowired
    BaseDictDataMapper baseDictDataMapper;

    public static IPage listToPage(List list, int pageNum, int pageSize) {
        List pageList = new ArrayList<>();
        int curIdx = pageNum > 1 ? (pageNum - 1) * pageSize : 0;
        for (int i = 0; i < pageSize && curIdx + i < list.size(); i++) {
            pageList.add(list.get(curIdx + i));
        }
        IPage page = new Page<>(pageNum, pageSize);
        page.setRecords(pageList);
        page.setTotal(list.size());
        return page;
    }

    //web数据统计 报警数据详情
    @Override
    public IPage<AlarmStatisticVo> list(String railwayCode, Integer startMonth, Integer endMonth, String alarmType, Integer pageNum, Integer pageSize, String userId) {
        List<AlarmStatisticVo> list = msgAlarmMapper.list(railwayCode, startMonth, endMonth, alarmType, userId);
        IPage listPage = listToPage(list, pageNum, pageSize);
        return listPage;
    }

    @Override
    public List<AlarmStatisticMonthDto> getCount(String railwayCode, Integer startMonth, Integer endMonth, String alarmType, String userId) {
        List<AlarmStatisticMonthDto> list = msgAlarmMapper.listDtoMonth(railwayCode, startMonth, endMonth, alarmType, userId);
        return list;
    }

    @Override
    public List<AlarmStatisticDto> exportExcel(AlarmStatisticResVo alarmStatisticResVo, String userId) {
        List<AlarmStatisticDto> listDto = msgAlarmMapper.listDto(alarmStatisticResVo.getRailwayCode(), alarmStatisticResVo.getStartMonth(),
                alarmStatisticResVo.getEndMonth(), alarmStatisticResVo.getAlarmType(), userId);
        return listDto;
    }

    @Override
    public List<AlarmStatisticMonthDto> exportExcelMonth(AlarmStatisticResVo alarmStatisticResVo, String userId) throws Exception {
        List<AlarmStatisticMonthDto> listDto = msgAlarmMapper.listDtoMonth(alarmStatisticResVo.getRailwayCode(), alarmStatisticResVo.getStartMonth(),
                alarmStatisticResVo.getEndMonth(), alarmStatisticResVo.getAlarmType(), userId);
        return listDto;
    }

    @Override
    public MsgAlarm selectByCameraCode(String cameraCode) {
        return msgAlarmMapper.selectByCameraCode(cameraCode);
    }

    @Override
    public IPage<MsgAlarm> queryPage(MsgAlarmVo vo) {
        int pageNum = Integer.parseInt(vo.getPageNum().toString());
        int pageSize = Integer.parseInt(vo.getPageSize().toString());
        com.github.pagehelper.Page<MsgAlarm> page = PageHelper.startPage(pageNum, pageSize)
                .doSelectPage(() -> msgAlarmMapper.selectMsgAlarmList(vo));
        com.baomidou.mybatisplus.extension.plugins.pagination.Page<MsgAlarm> pageR =
                new com.baomidou.mybatisplus.extension.plugins.pagination.Page<>(pageNum, pageSize);
        pageR.setRecords(page.getResult());
        pageR.setTotal(page.getTotal());
        return pageR;
    }

    @Override
    public MsgAlarm getByAlarmId(String alarmId) {
        return msgAlarmMapper.getByAlarmId(alarmId);
    }

}
